@@ -76,6 +76,7 @@ struct config_s
     int unmute_volume;
     int muted;
     int mute_on_exit;
+    int show_taglines;
 
     int keymap[ 8 * MAX_KEYSYMS ];
     char *keymap_arg[ 8 * MAX_KEYSYMS ];
@@ -243,6 +244,10 @@ static void parse_option( config_t *ct, xmlNodePtr node )
             ct->mute_on_exit = atoi( curval );
         }
 
+        if( !xmlStrcasecmp( name, BAD_CAST "ShowTaglines" ) ) {
+            ct->show_taglines = atoi( curval );
+        }
+
         if( !xmlStrcasecmp( name, BAD_CAST "ShowCC" ) ) {
             ct->cc = atoi( curval );
         }
@@ -580,6 +585,7 @@ static void print_usage( char **argv )
 {
     lfprintf( stderr, _("usage: %s [OPTION]...\n\n"), argv[ 0 ] );
     lfputs( _("  -a, --widescreen           16:9 mode.\n"), stderr );
+    lfputs( _("  -A, --nowidescreen         4:3 mode.\n"), stderr );
     lfputs( _("  -b, --vbidevice=DEVICE     VBI device (defaults to /dev/vbi0).\n"), stderr );
     lfputs( _("  -c, --channel=CHANNEL      Tune to the specified channel on startup.\n"), stderr );
     lfputs( _("  -d, --device=DEVICE        video4linux device (defaults to /dev/video0).\n"), stderr );
@@ -630,6 +636,7 @@ static void print_config_usage( char **argv )
 {
     lfprintf( stderr, _("usage: %s [OPTION]...\n\n"), argv[ 0 ] );
     lfputs( _("  -a, --widescreen           16:9 mode.\n"), stderr );
+    lfputs( _("  -A, --nowidescreen         4:3 mode.\n"), stderr );
     lfputs( _("  -b, --vbidevice=DEVICE     VBI device (defaults to /dev/vbi0).\n"), stderr );
     lfputs( _("  -c, --channel=CHANNEL      Tune to the specified channel on startup.\n"), stderr );
     lfputs( _("  -d, --device=DEVICE        video4linux device (defaults to /dev/video0).\n"), stderr );
@@ -718,6 +725,7 @@ config_t *config_new( void )
     ct->unmute_volume = -1;
     ct->muted = 0;
     ct->mute_on_exit = 1;
+    ct->show_taglines = 1;
 
     memset( ct->keymap, 0, sizeof( ct->keymap ) );
     memset( ct->keymap_arg, 0, sizeof( ct->keymap_arg ) );
@@ -877,6 +885,7 @@ int config_parse_tvtime_command_line( config_t *ct, int argc, char **argv )
         { "window", 0, 0, 'M' },
         { "slave", 0, 0, 'k' },
         { "widescreen", 0, 0, 'a' },
+        { "nowidescreen", 0, 0, 'A' },
         { "xmltv", 1, 0, 't' },
         { "xmltvlanguage", 1, 0, 'l' },
         { "display", 1, 0, 'X' },
@@ -886,13 +895,14 @@ int config_parse_tvtime_command_line( config_t *ct, int argc, char **argv )
     int option_index = 0;
     int saveoptions = 0;
     int filename_specified = 0;
-    char c;
+    int c;
 
     if( argc ) {
-        while( (c = getopt_long( argc, argv, "ahkmMsSvF:r:g:I:d:b:i:c:n:D:f:x:X:t:l:Qg:",
+        while( (c = getopt_long( argc, argv, "aAhkmMsSvF:r:g:I:d:b:i:c:n:D:f:x:X:t:l:Qg:",
                 long_options, &option_index )) != -1 ) {
             switch( c ) {
             case 'a': ct->aspect = 1; break;
+            case 'A': ct->aspect = 0; break;
             case 'k': ct->slave_mode = 1; break;
             case 'm': ct->fullscreen = 1; break;
             case 'M': ct->fullscreen = 0; break;
@@ -1015,6 +1025,7 @@ int config_parse_tvtime_config_command_line( config_t *ct, int argc, char **argv
         { "fullscreen", 0, 0, 'm' },
         { "window", 0, 0, 'M' },
         { "widescreen", 0, 0, 'a' },
+        { "nowidescreen", 0, 0, 'A' },
         { "xmltv", 2, 0, 't' },
         { "xmltvlanguage", 2, 0, 'l' },
         { "priority", 2, 0, 'R' },
@@ -1022,17 +1033,18 @@ int config_parse_tvtime_config_command_line( config_t *ct, int argc, char **argv
     };
     int option_index = 0;
     int filename_specified = 0;
-    char c;
+    int c;
 
     if( argc == 1 ) {
         print_config_usage( argv );
         return 0;
     }
 
-    while( (c = getopt_long( argc, argv, "ahmMF:g:I:d:b:i:c:n:D:f:x:t:l:R:",
+    while( (c = getopt_long( argc, argv, "aAhmMF:g:I:d:b:i:c:n:D:f:x:t:l:R:",
             long_options, &option_index )) != -1 ) {
         switch( c ) {
         case 'a': ct->aspect = 1; break;
+        case 'A': ct->aspect = 0; break;
         case 'm': ct->fullscreen = 1; break;
         case 'M': ct->fullscreen = 0; break;
         case 'F': if( ct->config_filename ) free( ct->config_filename );
@@ -1196,7 +1208,7 @@ int config_parse_tvtime_scanner_command_line( config_t *ct, int argc,
         { 0, 0, 0, 0 }
     };
     int option_index = 0;
-    char c;
+    int c;
 
     while( (c = getopt_long( argc, argv, "hF:d:i:n:",
             long_options, &option_index )) != -1 ) {
@@ -1630,3 +1642,8 @@ int config_get_mute_on_exit( config_t *ct )
     return ct->mute_on_exit;
 }
 
+int config_get_show_taglines( config_t *ct )
+{
+    return ct->show_taglines;
+}
+
