@@ -96,8 +96,6 @@ struct tvtime_osd_s
     int info_icon_xpos;
     int info_icon_ypos;
 
-    osd_graphic_t *backdrop;
-
     char channel_number_text[ 20 ];
     char channel_name_text[ 128 ];
     char tv_norm_text[ 20 ];
@@ -208,17 +206,6 @@ tvtime_osd_t *tvtime_osd_new( int width, int height, double pixel_aspect,
 
     fontfile = "tvtimeSansBold.ttf";
 
-    /* Disable the backdrop for now. */
-    if( 1 ) {
-        osd->backdrop = 0;
-    } else {
-        if( height == 576 ) {
-            osd->backdrop = osd_graphic_new( "backdrop-576.png", pixel_aspect, 256 );
-        } else {
-            osd->backdrop = osd_graphic_new( "backdrop-480.png", pixel_aspect, 256 );
-        }
-    }
-
     osd->databar = osd_rect_new();
     if( !osd->databar ) {
         free( osd );
@@ -530,7 +517,6 @@ void tvtime_osd_hold( tvtime_osd_t *osd, int hold )
             osd_string_set_hold( osd->strings[ i ].string, hold );
         }
     }
-    if( osd->backdrop ) osd_graphic_set_hold( osd->backdrop, hold );
     if( osd->film_logo ) osd_animation_set_hold( osd->film_logo, hold );
     if( osd->info_icon ) osd_animation_set_hold( osd->info_icon, hold );
 }
@@ -542,7 +528,6 @@ void tvtime_osd_clear( tvtime_osd_t *osd )
     for( i = 0; i < OSD_MAX_STRING_OBJECTS; i++ ) {
         osd_string_set_timeout( osd->strings[ i ].string, 0 );
     }
-    if( osd->backdrop ) osd_graphic_set_timeout( osd->backdrop, 0 );
     if( osd->film_logo ) osd_animation_set_timeout( osd->film_logo, 0 );
     if( osd->info_icon ) osd_animation_set_timeout( osd->info_icon, 0 );
     if( osd->chinfo ) {
@@ -557,9 +542,9 @@ void tvtime_osd_set_norm( tvtime_osd_t *osd, const char *norm )
     snprintf( osd->tv_norm_text, sizeof( osd->tv_norm_text ), "%s", norm );
 }
 
-void tvtime_osd_set_input( tvtime_osd_t *osd, const char *norm )
+void tvtime_osd_set_input( tvtime_osd_t *osd, const char *text )
 {
-    snprintf( osd->input_text, sizeof( osd->input_text ), "%s", norm );
+    snprintf( osd->input_text, sizeof( osd->input_text ), "%s", text );
 }
 
 void tvtime_osd_set_freq_table( tvtime_osd_t *osd, const char *freqtable )
@@ -679,15 +664,10 @@ void tvtime_osd_show_info( tvtime_osd_t *osd )
     time_t tm = time( 0 );
     char text[ 200 ];
     struct tm *curtime = localtime( &tm );
-    struct timeval tv;
 
     strftime( timestamp, 50, osd->timeformat, curtime );
     osd_string_show_text( osd->strings[ OSD_TIME_STRING ].string, timestamp, osd->delay );
 
-    gettimeofday( &tv, 0 );
-
-    if( osd->backdrop ) osd_graphic_set_timeout( osd->backdrop, osd->delay );
-
     osd_string_show_text( osd->strings[ OSD_CHANNEL_NUM ].string, osd->channel_number_text, osd->delay );
     osd_string_show_text( osd->strings[ OSD_NETWORK_NAME ].string, osd->network_name, osd->delay );
     osd_string_set_timeout( osd->strings[ OSD_SHOW_INFO ].string, osd->delay );
@@ -895,7 +875,6 @@ void tvtime_osd_advance_frame( tvtime_osd_t *osd )
         osd_string_advance_frame( osd->strings[ i ].string );
     }
 
-    if( osd->backdrop ) osd_graphic_advance_frame( osd->backdrop );
     if( osd->film_logo ) osd_animation_advance_frame( osd->film_logo );
     if( osd->info_icon ) osd_animation_advance_frame( osd->info_icon );
     osd_list_advance_frame( osd->list );
@@ -911,10 +890,6 @@ void tvtime_osd_composite_packed422_scanline( tvtime_osd_t *osd,
     int iconpush = 0;
     int i;
 
-    if( osd->backdrop && osd_graphic_visible( osd->backdrop ) && osd_graphic_active_on_scanline( osd->backdrop, scanline ) ) {
-        osd_graphic_composite_packed422_scanline( osd->backdrop, output, output, width, xpos, scanline );
-    }
-
     for( i = 0; i < OSD_MAX_STRING_OBJECTS; i++ ) {
         if( osd_string_visible( osd->strings[ i ].string ) ) {
             int start = osd->strings[ i ].ypos;
